@@ -1407,7 +1407,7 @@ folder_copy__response_cb (GObject *object,
 				       _("source and destination are the same"));
 		g_free (utf8_path);
 
-	} else if (strncmp (old_path, new_path, strlen (old_path)) == 0) {
+	} else if (path_in_path (old_path, new_path)) {
 		char *utf8_path;
 		
 		utf8_path = g_filename_to_utf8 (old_path, -1, NULL, NULL, NULL);
@@ -1622,8 +1622,10 @@ edit_current_folder_categories__done (gpointer data)
 		comments_save_categories (filename, cdata);
 		comment_data_free (cdata);
 
-		dir_list_remove_directory (fcdata->window->dir_list, filename);
-		dir_list_add_directory (fcdata->window->dir_list, filename);
+		if (path_in_path (fcdata->window->dir_list->path, filename)) {
+			dir_list_remove_directory (fcdata->window->dir_list, filename);
+			dir_list_add_directory (fcdata->window->dir_list, filename);
+		}
 	}
 
 	path_list_free (fcdata->file_list);
@@ -2649,7 +2651,7 @@ set_as_wallpaper (GThumbWindow   *window,
 		  WallpaperAlign  align)
 {
 	GConfClient *client;
-	char        *options;
+	char        *options = "none";
 
 	client = gconf_client_get_default ();
 
@@ -2734,7 +2736,7 @@ wallpaper_restore_command_impl (BonoboUIComponent *uic,
 				const gchar       *verbname)
 {
 	GThumbWindow *window = user_data;
-	gint align_type;
+	int           align_type = WALLPAPER_ALIGN_CENTERED;
 
 	if (strcmp (preferences.wallpaperAlign, "wallpaper") == 0)
 		align_type = WALLPAPER_ALIGN_TILED;
@@ -2941,7 +2943,7 @@ help_about_command_impl (BonoboUIComponent *uic,
 	static GtkWidget  *about;
 	GdkPixbuf         *logo;
 	const char        *authors[] = {
-		"Paolo Bacchilega <paolo.bacch@tin.it>",
+		"Paolo Bacchilega <paolo.bacchilega@libero.it>",
 		NULL
 	};
 	const char       *documenters [] = {
